@@ -404,7 +404,10 @@ class xydata():
         index = int(i)
         peak = self.peaks[self.peaks['cen']==cen]
         self.tmp_peakfit = self.fit_lorentz(peak.iloc[0].to_dict())
-        self.plot_fitting(self.tmp_peakfit)
+        if self.tmp_peakfit is None:
+            print('peak fitting failed.')
+        else:
+            self.plot_fitting(self.tmp_peakfit)
     
     # process peaks with widgets
     def process_peaks(self):
